summaryrefslogtreecommitdiff
path: root/indra/newview/llnearbychatbar.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llnearbychatbar.cpp')
-rw-r--r--indra/newview/llnearbychatbar.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/newview/llnearbychatbar.cpp b/indra/newview/llnearbychatbar.cpp
index 6cf8bcb417..ad98a29fb2 100644
--- a/indra/newview/llnearbychatbar.cpp
+++ b/indra/newview/llnearbychatbar.cpp
@@ -97,9 +97,9 @@ LLGestureComboList::LLGestureComboList(const LLGestureComboList::Params& p)
mList = LLUICtrlFactory::create<LLScrollListCtrl>(params);
// *HACK: adding list as a child to NonSideTrayView to make it fully visible without
// making it top control (because it would cause problems).
- gViewerWindow->getNonSideTrayView()->addChild(mList);
+ gViewerWindow->getFloaterViewHolder()->addChild(mList);
mList->setVisible(FALSE);
//****************************Gesture Part********************************/
@@ -97,9 +97,9 @@ LLGestureComboList::LLGestureComboList(const LLGestureComboList::Params& p)
mList = LLUICtrlFactory::create<LLScrollListCtrl>(params);
- // *HACK: adding list as a child to NonSideTrayView to make it fully visible without
+ // *HACK: adding list as a child to FloaterViewHolder to make it fully visible without
// making it top control (because it would cause problems).